@@ -35,14 +35,15 @@ def get_neg_bagging_fraction_params(y_train,params):
     return params
 
 
-def modelar(X_train=None,y_train=None,X_test=None,y_test=None,params=None,metric='average_precision',api="train_api",url=None):
+def modelar(X_train=None,y_train=None,X_test=None,y_test=None,params=None,metric=None,num_rounds=None,early_stop=None,log=None,random_state=42,api="train_api",url=None):
     start = time.time()
     model = None
     params = get_neg_bagging_fraction_params(y_train,params)
     
     if api=="train_api":
         params.update({"metric":metric})
-        model = l.lgb_model_train(X_train,y_train,X_test,y_test,params=params)
+        params.update({"seed":random_state})
+        model = l.lgb_model_train(X_train,y_train,X_test,y_test,params=params,num_rounds=num_rounds,early_stop=early_stop,log=log)
         y_prob_uno = model.predict(X_test, num_iteration=model.best_iteration) 
         
     elif api=="skl_api":
