@@ -119,6 +119,7 @@ def objective_with_prune(trial: Trial, fast_check=True, X=None,y=None,list_kpi=[
     bias = abs(mean_train_score - mean_valid_score)
     
     result_iter = {
+        'trial_number':trial.number,
         'bias': bias,
         'overfitting':with_bias,
         'mean_train_score':mean_train_score,
@@ -256,7 +257,7 @@ def fit_lgbm_with_pruning(trial, train, val, devices=(-1,),  cat_features=None,
     return model, kpi
 
 
-def lgb_model_optuna(X_train, y_train,n_trials=2,fast_check=True,score_rs='average_precision', params=None,n_jobs = 6,log=0):
+def lgb_model_optuna(X_train=None, y_train=None,n_trials=2,fast_check=True,score_rs='average_precision', params=None,n_jobs = 6,log=0):
     list_kpi_ = []
     sampler = optuna.samplers.RandomSampler(seed=10)
     pruner=optuna.pruners.MedianPruner(n_warmup_steps=5)
@@ -297,4 +298,25 @@ def get_params_by_value(trials_dataframe_,best_value_nob):
     best_trial_nob.columns = best_trial_nob.columns.str.replace('params_', '')
     best_params_nob = best_trial_nob.to_dict(orient='records')[0]
 
-    return best_params_nob
\ No newline at end of file
+    return best_params_nob
+
+
+def get_best_trial_number_nob(result_,nob_group="0.0-0.15"):
+    #result_ = result.copy()
+    labels = ["{0} - {1}".format(i, i + 0.1) for i in np.linspace(0,1,10,endpoint=True)] #, labels=labels
+    labels = ["0.0-0.15","0.15-0.2","0.2-0.3","0.3-0.4","0.4-0.5","0.5-0.6","0.6-0.7","0.7-0.8","0.8-0.9","0.9-1.0"]
+    intervalos = [0. , 0.15, 0.2, 0.3, 0.4, 0.5, 0.6, 0.7, 0.8, 0.9, 1. ]    
+    result_["bias_group"] = pd.cut(result_.bias, intervalos, right=False, labels=labels)
+    #result_["bias_group"] = pd.cut(result_.bias, np.linspace(0,1,11,endpoint=True), right=False, labels=labels)
+    final_result = result_[(result_.bias_group==nob_group) & (result_.overfitting==False)].sort_values(by=['mean_valid_score'], ascending=False)
+    trial_number = final_result['trial_number'].iloc[0]
+    return trial_number
+
+
+def get_kpis_by_trial_number(res,trial_number):
+
+    result_ = res[res.trial_number==trial_number].copy()
+    if len(result_)==0:
+        return None
+    result_dic = result_.to_dict(orient='records')[0]
+    return result_dic
\ No newline at end of file
